@@ -600,7 +600,7 @@ void pkgDPkgPM::ProcessDpkgStatusLine(char *line)
 
    // build the (prefix, pkgname, action) tuple, position of this
    // is different for "processing" or "status" messages
-   std::string prefix = APT::String::Strip(list[0]);
+   auto prefix = APT::String::Strip(list[0]);
    std::string pkgname;
    std::string action;
 
@@ -1516,8 +1516,15 @@ bool pkgDPkgPM::Go(APT::Progress::PackageManager *progress)
       int Fd = -1;
       Inhibitor()
       {
-	 if (_config->FindB("DPkg::Inhibit-Shutdown", true))
-	    Fd = Inhibit("shutdown", "APT", "APT is installing or removing packages", "block");
+        std::string to_inhibit;
+        if (_config->FindB("DPkg::Inhibit-Shutdown", true))
+          to_inhibit.append("shutdown:");
+        if (_config->FindB("DPkg::Inhibit-Sleep", true))
+          to_inhibit.append("sleep:");
+        // Remove trailing : separator
+        if (to_inhibit.length() > 0)
+          to_inhibit.pop_back();
+        Fd = Inhibit(to_inhibit.c_str(), "APT", "APT is installing or removing packages", "block");
       }
       ~Inhibitor()
       {
@@ -1876,7 +1883,7 @@ bool pkgDPkgPM::Go(APT::Progress::PackageManager *progress)
 	    {
 	       if (I->File[0] != '/')
 		  return _error->Error("Internal Error, Pathname to install is not absolute '%s'",I->File.c_str());
-	       auto file = flNotDir(I->File);
+	       std::string file{flNotDir(I->File)};
 	       if (flExtension(file) != "deb")
 		  file.append(".deb");
 	       std::string linkpath;
